==> fd-help-800.2017.12.14-noarch-1.tar.gz: fd-help/usr/share/doc/fd-help/misc.md <==
%%textdomain fatdoghelp
![ ](fatdog64.png)
# Miscellaneous other known issues

This page documents all the known issues that does not fit into other categories. Some of the issues have workarounds to make it work, some don't.

1. Guvcview crash when attempting to capture video.

**Cause**: portaudio library (used by guvcview) has incompatibilities with recent version of ALSA libraries included in Fatdog64 800.

**Workaround**: Before capturing video, click the "Audio Controls" tab and change the "Input Device" from **default**, or **sysdefault** to something else.

2. ROX crashes often. At the time or writing, have unexplained ROX crash on certain systems using radeon hardware.

**Cause**: Unknown, possible various reasons.

**Workaround**: Open terminal, and re-launch ROX, using the following commands (note: case is important, type them as you see them here):

```
killall -9 ROX-Filer
rox-desktop
```

3. Printing problem. My printer requires the vendor driver, and with great difficulty I have installed it. But it still does not print.

**Cause**: There are a great many reasons why it fails to work.

**Workaround**: Your best bet is to jump to the [Puppy Linux forum](http://murga-linux.com/puppy) and ask there. But before you do that, one of the possible cases is that your printer driver requires **ghostscript**. So fire up the package manager, and install **ghostscript**; and try printing again. Most of the time you don't even need to reboot. If that still fails, report the the Puppy Linux forum as above (and keep **ghostscript** installed, do not uninstall it again).

4. Sometimes, on certain systems (and on certain video adapters), after closing VLC (the media player), the VLC icon stays on the panel and cannot be removed, killed. The only way to remove it is by doing a hard-kill on it (`killall -9 vlc`). This is a known issue (see: [https://forum.manjaro.org/t/zombie-vlc-processes/51744](https://forum.manjaro.org/t/zombie-vlc-processes/51744), but it can be avoided by going into VLC's preference settings and change the **Video Output** preferences from **Auto** to **Xvideo output (XCB)**

==> fd-help-811.2020.08.26-noarch-1.tar.gz: fd-help/usr/share/doc/fd-help/misc.md <==
%%textdomain fatdoghelp
![ ](fatdog64.png)
# Miscellaneous other known issues

This page documents all the known issues that does not fit into other categories. Some of the issues have workarounds to make it work, some don't.

1. Guvcview crash when attempting to capture video.

**Cause**: portaudio library (used by guvcview) has incompatibilities with recent version of ALSA libraries included in Fatdog64 800.

**Workaround**: Before capturing video, click the "Audio Controls" tab and change the "Input Device" from **default**, or **sysdefault** to something else.

2. ROX crashes often. At the time or writing, have unexplained ROX crash on certain systems using radeon hardware.

**Cause**: Unknown, possible various reasons.

**Workaround**: Open terminal, and re-launch ROX, using the following commands (note: case is important, type them as you see them here):

```
killall -9 ROX-Filer
rox-desktop
```

3. Printing problem. My printer requires the vendor driver, and with great difficulty I have installed it. But it still does not print.

**Cause**: There are a great many reasons why it fails to work.

**Workaround**: Your best bet is to jump to the [Puppy Linux forum](https://forum.puppylinux.com/) and ask there. But before you do that, one of the possible cases is that your printer driver requires **ghostscript**. So fire up the package manager, and install **ghostscript**; and try printing again. Most of the time you don't even need to reboot. If that still fails, report the the Puppy Linux forum as above (and keep **ghostscript** installed, do not uninstall it again).

4. Sometimes, on certain systems (and on certain video adapters), after closing VLC (the media player), the VLC icon stays on the panel and cannot be removed, killed. The only way to remove it is by doing a hard-kill on it (`killall -9 vlc`). This is a known issue (see: [https://forum.manjaro.org/t/zombie-vlc-processes/51744](https://forum.manjaro.org/t/zombie-vlc-processes/51744), but it can be avoided by going into VLC's preference settings and change the **Video Output** preferences from **Auto** to **Xvideo output (XCB)**
